@@ -1,5 +1,5 @@
 from .cross_encoder_client import CrossEncoderClient
-from .embedding_client import Embedder, OpenAIEmbedder
+from .embedding_client import Embedder, OpenAIEmbedder, PiEmbedder
 from .indexing_client import IndexingClient
 from .pi_scorer_client import PiScorerClient
 from .query_fanout_client import QueryFanoutClient
@@ -11,6 +11,7 @@ __all__ = [
     "Embedder",
     "IndexingClient",
     "OpenAIEmbedder",
+    "PiEmbedder",
     "CrossEncoderClient",
     "QueryFanoutClient",
 ]
