@@ -11,7 +11,7 @@ import subprocess
 import webbrowser
 import zipfile
 from pathlib import Path
-from typing import Optional
+from typing import Any, Optional
 
 import typer
 import websockets
@@ -157,7 +157,7 @@ def index(
         help="Corpus name that will store the indexed documents.",
     ),
     id_column: Optional[str] = typer.Option(
-        "url", "--id", help="Optional column to use as the document identifier."
+        None, "--id", help="Optional column to use as the document identifier."
     ),
     text_column: str = typer.Option(
         "schema_object",
@@ -165,10 +165,21 @@ def index(
         help="Column that contains the document text.",
     ),
     embedding_column: Optional[str] = typer.Option(
-        "schema_object_embedding",
+        None,
         "--embedding",
         help="Optional column that contains pre-computed embeddings.",
     ),
+    embedding_dim: Optional[int] = typer.Option(
+        None,
+        "--embedding-dim",
+        min=1,
+        help="Optional embedding dimension override for the indexer.",
+    ),
+    embedding_model: Optional[str] = typer.Option(
+        None,
+        "--embedding-model",
+        help="Optional embedding model override for the indexer.",
+    ),
 ):
     """
     Index a Hugging Face dataset into the configured OpenSearch instance.
@@ -185,9 +196,33 @@ def index(
         for example in ds
     ]
 
+    if embedding_model == "pi-embedding":
+        if embedding_dim is None:
+            raise typer.BadParameter(
+                "--embedding-dim is required when --embedding-model is set to pi-embedding",
+                param_hint="--embedding-dim",
+            )
+        if embedding_dim != 256:
+            raise typer.BadParameter(
+                "--embedding-dim must be 256 when --embedding-model is pi-embedding",
+                param_hint="--embedding-dim",
+            )
+
+    index_config: dict[str, Any] | None = None
+    if embedding_dim is not None or embedding_model is not None:
+        index_config = {}
+        if embedding_dim is not None:
+            index_config["dimensions"] = embedding_dim
+        if embedding_model is not None:
+            index_config["model"] = embedding_model
+
     async def _run() -> None:
         async with PiRagBoxIndexer() as indexer:
-            await indexer.index_corpus(documents=documents, corpus_name=corpus)
+            await indexer.index_corpus(
+                documents=documents,
+                corpus_name=corpus,
+                config=index_config,
+            )
             corpora = await indexer.list_corpora()
             rprint(
                 "[bold green]Indexing complete.[/bold green] "
@@ -426,8 +461,8 @@ def create_directory_zip(directory_path: Path) -> bytes:
     """
     zip_buffer = io.BytesIO()
 
-    with zipfile.ZipFile(zip_buffer, 'w', zipfile.ZIP_DEFLATED) as zip_file:
-        for file_path in directory_path.rglob('*'):
+    with zipfile.ZipFile(zip_buffer, "w", zipfile.ZIP_DEFLATED) as zip_file:
+        for file_path in directory_path.rglob("*"):
             if file_path.is_file():
                 # Get relative path from the directory itself (not its parent)
                 arcname = file_path.relative_to(directory_path)
@@ -465,7 +500,7 @@ async def run_via_modal(
         "-m",
         "pilabs.search_service.modal_main",
     ]
-    
+
     rprint(f"[dim] Command:[/dim] {' '.join(command)}")
 
     try:
@@ -543,17 +578,16 @@ async def run_via_sandbox_service(
 
             # Send zip data
             await websocket.send(zip_data)
-            rprint("[bold green]→[/bold green] Code uploaded, starting Modal serve...\n")
+            rprint(
+                "[bold green]→[/bold green] Code uploaded, starting Modal serve...\n"
+            )
 
             # Stream output until exit or shutdown requested
             exit_code = 0
             while not shutdown_requested.is_set():
                 try:
                     # Wait for message with timeout to check shutdown flag
-                    msg_str = await asyncio.wait_for(
-                        websocket.recv(),
-                        timeout=0.5
-                    )
+                    msg_str = await asyncio.wait_for(websocket.recv(), timeout=0.5)
                     msg = json.loads(msg_str)
                     msg_type = msg.get("type")
 
@@ -598,13 +632,16 @@ async def run_via_sandbox_service(
             return exit_code
 
     except ConnectionRefusedError:
-        rprint(f"[bold red]✗[/bold red] Could not connect to sandbox service at {sandbox_url}")
+        rprint(
+            f"[bold red]✗[/bold red] Could not connect to sandbox service at {sandbox_url}"
+        )
         rprint("\n[dim]Make sure the sandbox-service is running:[/dim]")
         rprint("[dim]  cd sandbox-service && ./sandbox-service[/dim]")
         return 1
     except Exception as e:
         rprint(f"[bold red]✗[/bold red] Unexpected error: {str(e)}")
         import traceback
+
         traceback.print_exc()
         return 1
 
@@ -622,7 +659,7 @@ def serve(
         "--use-sandbox/--no-sandbox",
         help="Whether to use the local sandbox service for deployment",
         show_default=True,
-    )
+    ),
 ):
     """
     Launch a Modal stack with custom configuration.
